from sqlalchemy import Column, func, ForeignKey
from sqlalchemy.orm import relationship
from sqlalchemy.dialects.postgresql import UUID, JSON, TIMESTAMP, TEXT
from uuid import uuid4
from sqlalchemy.ext.declarative import declarative_base
import database_orm.models as models

Base = declarative_base()


class TaskRequest(Base):
    __tablename__ = 'task_requests'

    uuid = Column(UUID(as_uuid=True), primary_key=True, default=uuid4)

    task_uuid = Column(UUID(as_uuid=True), ForeignKey(models.tasks.Task.uuid), nullable=False, index=True)
    task = relationship(models.tasks.Task, back_populates="requests")

    result = relationship(models.task_results.TaskResult, uselist=False, back_populates="task_request")

    statuses = relationship(models.task_statuses.TaskStatus, back_populates="task_request")

    data = Column(JSON)

    callback = Column(TEXT)

    created_at = Column(TIMESTAMP, server_default=func.current_timestamp())
    updated_at = Column(TIMESTAMP, onupdate=func.current_timestamp())
